"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = apiReauthUser;
const varDatabaseDbHandler_1 = __importDefault(require("../../backend/varDatabaseDbHandler"));
/**
 * # Re-authenticate API user
 */
function apiReauthUser(_a) {
    return __awaiter(this, arguments, void 0, function* ({ existingUser, database, additionalFields, }) {
        const dbAppend = global.DSQL_USE_LOCAL
            ? ""
            : database
                ? `${database}.`
                : "";
        let foundUser = (existingUser === null || existingUser === void 0 ? void 0 : existingUser.id) && existingUser.id.toString().match(/./)
            ? yield (0, varDatabaseDbHandler_1.default)({
                queryString: `SELECT * FROM ${dbAppend}users WHERE id=?`,
                queryValuesArray: [existingUser.id.toString()],
                database,
            })
            : null;
        if (!foundUser || !foundUser[0])
            return {
                success: false,
                payload: null,
                msg: "No user found",
            };
        let csrfKey = Math.random().toString(36).substring(2) +
            "-" +
            Math.random().toString(36).substring(2);
        let userPayload = {
            id: foundUser[0].id,
            first_name: foundUser[0].first_name,
            last_name: foundUser[0].last_name,
            username: foundUser[0].username,
            email: foundUser[0].email,
            phone: foundUser[0].phone,
            social_id: foundUser[0].social_id,
            image: foundUser[0].image,
            image_thumbnail: foundUser[0].image_thumbnail,
            verification_status: foundUser[0].verification_status,
            social_login: foundUser[0].social_login,
            social_platform: foundUser[0].social_platform,
            csrf_k: csrfKey,
            more_data: foundUser[0].more_user_data,
            logged_in_status: true,
            date: Date.now(),
        };
        if (additionalFields &&
            Array.isArray(additionalFields) &&
            additionalFields.length > 0) {
            additionalFields.forEach((key) => {
                userPayload[key] = foundUser[0][key];
            });
        }
        return {
            success: true,
            msg: "Login Successful",
            payload: userPayload,
            csrf: csrfKey,
        };
    });
}
